@@ -7,6 +7,7 @@ Cloud Provider Configs
 import os
 import json
 import pathlib
+import multiprocessing as mp
 from typing import Optional, Union, Any, Dict, TYPE_CHECKING
 
 from pydantic import Json
@@ -66,6 +67,8 @@ class CloudConfig(ConfigModel):
     s3compat_access_token: Optional[str] = ""
     s3compat_config: Optional[Json] = None
 
+    max_workers: Optional[int] = mp.cpu_count() * 2
+
     def create_adc(self, data: Union[str, Dict[str, Any]], path: str = None):
         """
         Create a new ADC based on the passed data and writes it to 
@@ -148,18 +151,22 @@ class CloudConfig(ConfigModel):
         if self.aws_access_key_id:
             os.system['AWS_ACCESS_KEY_ID'] = self.aws_access_key_id
             os.system['AWS_SECRET_ACCESS_KEY'] = self.aws_secret_access_key
+        
+        if self.minio_endpoint:
+            os.system['MINIO_ENDPOINT'] = self.minio_endpoint
         if self.set_s3_endpoint:
             os.system['S3_ENDPOINT'] = self.get_s3_endpoint()
         if self.minio_access_key:
             os.system['MINIO_ACCESS_KEY'] = self.minio_access_key
             os.system['MINIO_SECRET_KEY'] = self.minio_secret_key
-        if self.minio_endpoint:
-            os.system['MINIO_ENDPOINT'] = self.minio_endpoint
+        
 
     def update_auth(self, **config):
         self.update_config(**config)
         self.set_auth_env()
-        
+    
+    class Config:
+        env_prefix = ""
         
 
 
